@@ -485,7 +485,6 @@ void CtActions::codebox_save_to_file()
     g_file_set_contents(filepath.c_str(), text.c_str(), (gssize)text.bytes(), nullptr);
 }
 
-// Increase CodeBox Width
 void CtActions::codebox_increase_width()
 {
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
@@ -502,7 +501,6 @@ void CtActions::codebox_increase_width()
     _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
 }
 
-// Decrease CodeBox Width
 void CtActions::codebox_decrease_width()
 {
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
@@ -520,7 +518,6 @@ void CtActions::codebox_decrease_width()
     }
 }
 
-// Increase CodeBox Height
 void CtActions::codebox_increase_height()
 {
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
@@ -532,7 +529,6 @@ void CtActions::codebox_increase_height()
     _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
 }
 
-// Decrease CodeBox Height
 void CtActions::codebox_decrease_height()
 {
     if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
@@ -566,35 +562,58 @@ void CtActions::table_column_add()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->column_add(curr_table_anchor->current_column());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_column_delete()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->column_delete(curr_table_anchor->current_column());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_column_left()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->column_move_left(curr_table_anchor->current_column());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_column_right()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->column_move_right(curr_table_anchor->current_column());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
+}
+
+void CtActions::table_column_increase_width()
+{
+    if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
+    curr_table_anchor->set_col_width(curr_table_anchor->get_col_width() + CtCodebox::CB_WIDTH_HEIGHT_STEP_PIX);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
+}
+
+void CtActions::table_column_decrease_width()
+{
+    if (_pCtMainWin->curr_tree_iter().get_node_read_only()) return;
+    if (curr_table_anchor->get_col_width() - CtCodebox::CB_WIDTH_HEIGHT_STEP_PIX >= CtCodebox::CB_WIDTH_LIMIT_MIN) {
+        curr_table_anchor->set_col_width(curr_table_anchor->get_col_width() - CtCodebox::CB_WIDTH_HEIGHT_STEP_PIX);
+        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+        _pCtMainWin->re_load_current_buffer();
+    }
 }
 
 void CtActions::table_row_add()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->row_add(curr_table_anchor->current_row());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_row_cut()
@@ -628,45 +647,53 @@ void CtActions::table_row_delete()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->row_delete(curr_table_anchor->current_row());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_row_up()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->row_move_up(curr_table_anchor->current_row());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_row_down()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
     curr_table_anchor->row_move_down(curr_table_anchor->current_row());
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_rows_sort_descending()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
-    if (curr_table_anchor->row_sort_desc())
-        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    if (curr_table_anchor->row_sort_desc()) {
+        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+        _pCtMainWin->re_load_current_buffer();
+    }
 }
 
 void CtActions::table_rows_sort_ascending()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
-    if (curr_table_anchor->row_sort_asc())
-        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    if (curr_table_anchor->row_sort_asc()) {
+        _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+        _pCtMainWin->re_load_current_buffer();
+    }
 }
 
 void CtActions::table_edit_properties()
 {
     if (!_is_curr_node_not_read_only_or_error()) return;
-    _pCtMainWin->get_ct_config()->tableColWidth = curr_table_anchor->get_col_width();
+    _pCtMainWin->get_ct_config()->tableColWidthDefault = curr_table_anchor->get_col_width_default();
     if (CtDialogs::TableHandleResp::Cancel == CtDialogs::table_handle_dialog(_pCtMainWin, _("Edit Table Properties"), false/*is_insert*/))
         return;
-    curr_table_anchor->set_col_width(_pCtMainWin->get_ct_config()->tableColWidth);
-    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true /*new_machine_state*/);
+    curr_table_anchor->set_col_width_default(_pCtMainWin->get_ct_config()->tableColWidthDefault);
+    _pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf, true/*new_machine_state*/);
+    _pCtMainWin->re_load_current_buffer();
 }
 
 void CtActions::table_export()
