@@ -27,6 +27,7 @@
 #include "ct_storage_control.h"
 #include "config.h"
 #include "ct_logging.h"
+#include <iostream>
 
 CtApp::CtApp() : Gtk::Application("com.giuspen.cherrytree", Gio::APPLICATION_HANDLES_OPEN)
 {
@@ -39,7 +40,9 @@ CtApp::CtApp() : Gtk::Application("com.giuspen.cherrytree", Gio::APPLICATION_HAN
     _uCtCfg.reset(new CtConfig());
     //std::cout << _uCtCfg->specialChars.size() << "\t" << _uCtCfg->specialChars << std::endl;
 
+    std::string user_dir_icons = Glib::build_filename(Glib::get_user_config_dir(), CtConst::APP_NAME, "icons");
     _rIcontheme = Gtk::IconTheme::get_default();
+    _rIcontheme->append_search_path(user_dir_icons);
     _rIcontheme->add_resource_path("/icons/");
     //_print_gresource_icons();
 
@@ -73,9 +76,9 @@ CtApp::CtApp() : Gtk::Application("com.giuspen.cherrytree", Gio::APPLICATION_HAN
     });
     _rStatusIcon->signal_popup_menu().connect([&](guint button, guint32 activate_time){
         Gtk::Menu* systrayMenu = Gtk::manage(new Gtk::Menu());
-        auto item1 = CtMenu::create_menu_item(GTK_WIDGET(systrayMenu->gobj()), _("Show/Hide _CherryTree"), CtConst::APP_NAME, _("Toggle Show/Hide CherryTree"));
+        auto item1 = CtMenu::create_menu_item(systrayMenu, _("Show/Hide _CherryTree"), CtConst::APP_NAME, _("Toggle Show/Hide CherryTree"));
         item1->signal_activate().connect([&] {_systray_show_hide_windows();});
-        auto item2 = CtMenu::create_menu_item(GTK_WIDGET(systrayMenu->gobj()), _("_Exit CherryTree"), "ct_quit-app", _("Exit from CherryTree"));
+        auto item2 = CtMenu::create_menu_item(systrayMenu, _("_Exit CherryTree"), "ct_quit-app", _("Exit from CherryTree"));
         item2->signal_activate().connect([&] { _systray_close_all(); });
         systrayMenu->show_all();
         systrayMenu->popup(button, activate_time);
@@ -323,6 +326,7 @@ void CtApp::_systray_close_all()
 
 void CtApp::_add_main_option_entries()
 {
+    add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL,     "version",            'V', _("Print CherryTree version"));
     add_main_option_entry(Gio::Application::OPTION_TYPE_STRING,   "node",               'n', _("Node name to focus"));
     add_main_option_entry(Gio::Application::OPTION_TYPE_FILENAME, "export_to_html_dir", 'x', _("Export to HTML at specified directory path"));
     add_main_option_entry(Gio::Application::OPTION_TYPE_FILENAME, "export_to_txt_dir",  't', _("Export to Text at specified directory path"));
@@ -345,6 +349,10 @@ int CtApp::_on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& rOpti
         return -1; // Keep going
     }
 
+    if (rOptions->contains("version")) {
+        std::cout << "CherryTree " << CtConst::CT_VERSION << std::endl;
+        return 0; // to exit app
+    }
     rOptions->lookup_value("node", _node_to_focus);
     rOptions->lookup_value("export_to_html_dir", _export_to_html_dir);
     rOptions->lookup_value("export_to_txt_dir", _export_to_txt_dir);
