@@ -88,7 +88,7 @@ CtMainWin::CtMainWin(bool             no_gui,
     _pRecentDocsSubmenu = CtMenu::find_menu_item(_pMenuBar, "RecentDocsMenu");
     _pSpecialCharsSubmenu = CtMenu::find_menu_item(_pMenuBar, "SpecialCharsMenu");
     _pMenuBar->show_all();
-    gtk_window_add_accel_group(GTK_WINDOW(gobj()), _uCtMenu->default_accel_group());
+    add_accel_group(_uCtMenu->get_accel_group());
     _pToolbars = _uCtMenu->build_toolbars(_pRecentDocsMenuToolButton);
 
     _vboxMain.pack_start(*_pMenuBar, false, false);
@@ -176,10 +176,12 @@ void CtMainWin::apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer,
     if (CtConst::TABLE_CELL_TEXT_ID == syntax)
     {
         text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->taStyleScheme));
+        text_buffer->set_highlight_matching_brackets(_pCtConfig->rtHighlMatchBra);
     }
     else if (CtConst::RICH_TEXT_ID == syntax)
     {
         text_buffer->set_style_scheme(_pGsvStyleSchemeManager->get_scheme(_pCtConfig->rtStyleScheme));
+        text_buffer->set_highlight_matching_brackets(_pCtConfig->rtHighlMatchBra);
     }
     else
     {
@@ -193,17 +195,54 @@ void CtMainWin::apply_syntax_highlighting(Glib::RefPtr<Gsv::Buffer> text_buffer,
             text_buffer->set_language(_pGsvLanguageManager->get_language(syntax));
             text_buffer->set_highlight_syntax(true);
         }
-        text_buffer->set_highlight_matching_brackets(true);
+        text_buffer->set_highlight_matching_brackets(_pCtConfig->ptHighlMatchBra);
     }
     text_buffer->set_data(CtConst::STYLE_APPLIED_ID, (void*)1);
 }
 
+void CtMainWin::resetup_for_syntax(const char target/*'r':RichText, 'p':PlainTextNCode*/)
+{
+    CtTreeIter treeIter = curr_tree_iter();
+    if ('r' == target) {
+        // we have to reapply only if the selected node is rich text
+        if (treeIter and treeIter.get_node_syntax_highlighting() == CtConst::RICH_TEXT_ID) {
+            _ctTextview.setup_for_syntax(treeIter.get_node_syntax_highlighting());
+        }
+    }
+    else if ('p' == target) {
+        // we have to reapply only if the selected node is rich text
+        if (treeIter and treeIter.get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID) {
+            _ctTextview.setup_for_syntax(treeIter.get_node_syntax_highlighting());
+        }
+        // we need also to reapply to all codeboxes that were already loaded
+        get_tree_store().get_store()->foreach([&](const Gtk::TreePath& /*treePath*/, const Gtk::TreeIter& treeIter)->bool
+        {
+            CtTreeIter node = get_tree_store().to_ct_tree_iter(treeIter);
+            if (node.get_node_is_rich_text() and node.get_node_buffer_already_loaded()) {
+                // let's look for codeboxes
+                std::list<CtAnchoredWidget*> anchoredWidgets = node.get_embedded_pixbufs_tables_codeboxes_fast();
+                for (auto pAnchoredWidget : anchoredWidgets) {
+                    if (CtAnchWidgType::CodeBox == pAnchoredWidget->get_type()) {
+                        CtCodebox* pCodebox = dynamic_cast<CtCodebox*>(pAnchoredWidget);
+                        if (pCodebox) {
+                            pCodebox->get_text_view().setup_for_syntax(pCodebox->get_syntax_highlighting());
+                        }
+                    }
+                }
+            }
+            return false; /* false for continue */
+        });
+    }
+    else {
+        spdlog::debug("bad reapply target {}", target);
+    }
+}
+
 void CtMainWin::reapply_syntax_highlighting(const char target/*'r':RichText, 'p':PlainTextNCode, 't':Table*/)
 {
-    // clean up applied style for created buffers
     get_tree_store().get_store()->foreach([&](const Gtk::TreePath& /*treePath*/, const Gtk::TreeIter& treeIter)->bool
     {
-        auto node = get_tree_store().to_ct_tree_iter(treeIter);
+        CtTreeIter node = get_tree_store().to_ct_tree_iter(treeIter);
         switch (target) {
             case 'r': {
                 if (node.get_node_is_rich_text()) {
@@ -236,7 +275,7 @@ void CtMainWin::reapply_syntax_highlighting(const char target/*'r':RichText, 'p'
                 }
             } break;
             default:
-                spdlog::debug("bad theme target");
+                spdlog::debug("bad reapply target {}", target);
                 break;
         }
         return false; /* false for continue */
@@ -557,7 +596,6 @@ void CtMainWin::config_apply()
     }
     _hPaned.property_position() = _pCtConfig->hpanedPos;
 
-
     show_hide_tree_view(_pCtConfig->treeVisible);
     show_hide_win_header(_pCtConfig->showNodeNameHeader);
     _ctWinHeader.lockIcon.hide();
@@ -596,14 +634,17 @@ void CtMainWin::config_update_data_from_curr_status()
 
 void CtMainWin::update_theme()
 {
-    auto font_to_string = [](const Pango::FontDescription& font, const Glib::ustring& /*fallbackFont*/)->std::string
+    auto font_to_string = [](const Pango::FontDescription& font, const Glib::ustring& fallbackFont)->std::string
     {
-        // fallback font doesn't work on Win32 because of pango
-        // add fallback font (to help with font on Win; on Linux, font works ok without explicit fallback
-        // return " { font-family: \"" + font.get_family() + "\",\"" + fallbackFont +  "\";"
-        //            "font-size: " + std::to_string(font.get_size()/Pango::SCALE) + "pt; } ";
+        // adds fallback font on Win32; on Linux, fonts work ok without explicit fallback
+#ifdef _WIN32
+        return " { font-family: \"" + Glib::locale_from_utf8(font.get_family()) + "\",\"" + fallbackFont +  "\""
+                    "; font-size: " + std::to_string(font.get_size()/Pango::SCALE) + "pt; } ";
+#else
+        (void)fallbackFont; // to silence the warning
         return std::string{" { font-family: "} + Glib::locale_from_utf8(font.get_family()) +
                  "; font-size: " + std::to_string(font.get_size()/Pango::SCALE) + "pt; } ";
+#endif
     };
 
     std::string rtFont = font_to_string(Pango::FontDescription(_pCtConfig->rtFont), _pCtConfig->fallbackFontFamily);
@@ -729,7 +770,7 @@ void CtMainWin::window_header_update()
         gint64 curr_node = curr_tree_iter().get_node_id();
         int button_idx = 0;
         auto buttons = _ctWinHeader.buttonBox.get_children();
-        auto nodes = get_state_machine().get_visited_nodes_list();
+        auto nodes = _ctStateMachine.get_visited_nodes_list();
         _ctWinHeader.button_to_node_id.clear();
         for (auto iter = nodes.rbegin(); iter != nodes.rend(); ++iter)
         {
@@ -994,7 +1035,7 @@ bool CtMainWin::file_open(const fs::path& filepath, const std::string& node_to_f
     bool node_is_set = false;
     if (node_to_focus != "") {
         if (CtTreeIter node = get_tree_store().get_node_from_node_name(node_to_focus)) {
-            get_tree_store().treeview_safe_set_cursor(_uCtTreeview.get(), node);
+            _uCtTreeview->set_cursor_safe(node);
             _ctTextview.grab_focus();
             node_is_set = true;
         }
@@ -1072,7 +1113,7 @@ void CtMainWin::file_save(bool need_vacuum)
     if (_uCtStorage->save(need_vacuum, error))
     {
         update_window_save_not_needed();
-        get_state_machine().update_state();
+        _ctStateMachine.update_state();
     }
     else
     {
@@ -1174,7 +1215,7 @@ bool CtMainWin::file_insert_plain_text(const fs::path& filepath)
             node_content = str::sanitize_bad_symbols(node_content);
             std::string name = filepath.filename().string();
             get_ct_actions()->_node_child_exist_or_create(Gtk::TreeIter(), name);
-            get_text_view().get_buffer()->insert(get_text_view().get_buffer()->end(), node_content);
+            _ctTextview.get_buffer()->insert(_ctTextview.get_buffer()->end(), node_content);
             g_free(text);
             return true;
         }
@@ -1190,7 +1231,7 @@ void CtMainWin::reset()
     auto on_scope_exit = scope_guard([&](void*) { user_active() = true; });
     user_active() = false;
 
-    get_state_machine().reset();
+    _ctStateMachine.reset();
 
     _uCtStorage.reset(CtStorageControl::create_dummy_storage(this));
 
@@ -1253,7 +1294,7 @@ void CtMainWin::update_selected_node_statusbar_info()
         }
         if (_pCtConfig->wordCountOn)
         {
-            statusbar_text += separator_text + _("Word Count") + _(": ") + std::to_string(CtTextIterUtil::get_words_count(get_text_view().get_buffer()));
+            statusbar_text += separator_text + _("Word Count") + _(": ") + std::to_string(CtTextIterUtil::get_words_count(_ctTextview.get_buffer()));
         }
         if (treeIter.get_node_creating_time() > 0)
         {
@@ -1329,7 +1370,7 @@ void CtMainWin::update_window_save_needed(const CtSaveNeededUpdType update_type,
             rm_node_ids.push_back(top_node_id);
             _uCtTreestore->pending_rm_db_nodes(rm_node_ids);
             for (auto node_id: rm_node_ids)
-                get_state_machine().delete_states(node_id);
+                _ctStateMachine.delete_states(node_id);
         } break;
         case CtSaveNeededUpdType::book:
         {
@@ -1337,7 +1378,17 @@ void CtMainWin::update_window_save_needed(const CtSaveNeededUpdType update_type,
         } break;
     }
     if (new_machine_state && treeIter)
-        get_state_machine().update_state(treeIter);
+        _ctStateMachine.update_state(treeIter);
+}
+
+void CtMainWin::re_load_current_buffer(const bool new_machine_state)
+{
+    CtTreeIter currTreeIter = curr_tree_iter();
+    if (new_machine_state) {
+        _ctStateMachine.update_state(currTreeIter);
+    }
+    std::shared_ptr<CtNodeState> currState = _ctStateMachine.requested_state_current(currTreeIter.get_node_id());
+    load_buffer_from_state(currState, currTreeIter);
 }
 
 // Load Text Buffer from State Machine
@@ -1362,18 +1413,32 @@ void CtMainWin::load_buffer_from_state(std::shared_ptr<CtNodeState> state, CtTre
     }
 
     // xml storage doesn't have widgets, so load them seperatrly
-    for (auto widgetState: state->widgetStates)
+    for (auto widgetState : state->widgetStates) {
         widgets.push_back(widgetState->to_widget(this));
-    for (auto widget: widgets)
+    }
+    for (auto widget : widgets) {
         widget->insertInTextBuffer(gsv_buffer);
-    get_tree_store().addAnchoredWidgets(tree_iter, widgets, &get_text_view());
+    }
+    get_tree_store().addAnchoredWidgets(tree_iter, widgets, &_ctTextview);
 
     text_buffer->end_not_undoable_action();
     text_buffer->set_modified(false);
 
-    get_text_view().set_buffer(text_buffer);
-    get_text_view().set_spell_check(curr_tree_iter().get_node_is_rich_text());
+    _uCtTreestore->text_view_apply_textbuffer(tree_iter, &_ctTextview);
+    if (widgets.size() > 0) {
+        // workaround for nodes with anchored widgets very first visualisation glitches
+        while (gtk_events_pending()) gtk_main_iteration();
+        CtTreeIter emptyTreeIter{};
+        _uCtTreestore->text_view_apply_textbuffer(emptyTreeIter, &_ctTextview);
+        while (gtk_events_pending()) gtk_main_iteration();
+        _uCtTreestore->text_view_apply_textbuffer(tree_iter, &_ctTextview);
+    }
+    _ctTextview.grab_focus();
+
+    _ctTextview.set_spell_check(curr_tree_iter().get_node_is_rich_text());
+
     text_buffer->place_cursor(text_buffer->get_iter_at_offset(state->cursor_pos));
+    (void)_try_move_focus_to_anchored_widget_if_on_it();
     Glib::signal_idle().connect_once([&](){
         auto insert_offset = _ctTextview.get_buffer()->get_insert()->get_iter().get_offset();
         if (_ctTextview.place_cursor_onscreen()) { // scroll if only cursor wasn't visible
@@ -1440,10 +1505,11 @@ void CtMainWin::_on_treeview_cursor_changed()
         _prevTreeIter = treeIter;
         return;
     }
+    const gint64 nodeId = treeIter.get_node_id();
     if (_prevTreeIter)
     {
         const gint64 prevNodeId = _prevTreeIter.get_node_id();
-        if (prevNodeId == treeIter.get_node_id()) {
+        if (prevNodeId == nodeId) {
             return;
         }
         Glib::RefPtr<Gsv::Buffer> rTextBuffer = _prevTreeIter.get_node_text_buffer();
@@ -1451,24 +1517,42 @@ void CtMainWin::_on_treeview_cursor_changed()
         {
             _fileSaveNeeded = true;
             rTextBuffer->set_modified(false);
-            get_state_machine().update_state(_prevTreeIter);
+            _ctStateMachine.update_state(_prevTreeIter);
         }
         _nodesCursorPos[prevNodeId] = rTextBuffer->property_cursor_position();
     }
+
     _uCtTreestore->text_view_apply_textbuffer(treeIter, &_ctTextview);
-    auto mapIter = _nodesCursorPos.find(treeIter.get_node_id());
-    if (mapIter != _nodesCursorPos.end() and mapIter->second > 0) {
-        text_view_apply_cursor_position(treeIter, mapIter->second);
-    } else {
-        text_view_apply_cursor_position(treeIter, 0);
+
+    if (user_active()) {
+        // workaround for nodes with anchored widgets very first visualisation glitches
+        if ( _nodesCursorPos.count(nodeId) == 0 and
+             treeIter.get_embedded_pixbufs_tables_codeboxes_fast().size() > 0 )
+        {
+            while (gtk_events_pending()) gtk_main_iteration();
+            CtTreeIter emptyTreeIter{};
+            _uCtTreestore->text_view_apply_textbuffer(emptyTreeIter, &_ctTextview);
+            while (gtk_events_pending()) gtk_main_iteration();
+            _uCtTreestore->text_view_apply_textbuffer(treeIter, &_ctTextview);
+        }
+
+        // NOTE: text_view_apply_cursor_position() uses Glib::signal_idle().connect_once()
+        //       which is hanging the tree nodes iteration
+        auto mapIter = _nodesCursorPos.find(nodeId);
+        if (mapIter != _nodesCursorPos.end() and mapIter->second > 0) {
+            text_view_apply_cursor_position(treeIter, mapIter->second);
+        } else {
+            text_view_apply_cursor_position(treeIter, 0);
+        }
+
+        menu_update_bookmark_menu_item(_uCtTreestore->is_node_bookmarked(nodeId));
+        window_header_update();
+        window_header_update_lock_icon(treeIter.get_node_read_only());
+        window_header_update_bookmark_icon(_uCtTreestore->is_node_bookmarked(nodeId));
+        update_selected_node_statusbar_info();
     }
 
-    menu_update_bookmark_menu_item(_uCtTreestore->is_node_bookmarked(treeIter.get_node_id()));
-    window_header_update();
-    window_header_update_lock_icon(treeIter.get_node_read_only());
-    window_header_update_bookmark_icon(_uCtTreestore->is_node_bookmarked(treeIter.get_node_id()));
-    update_selected_node_statusbar_info();
-    get_state_machine().node_selected_changed(treeIter.get_node_id());
+    _ctStateMachine.node_selected_changed(nodeId);
 
     _prevTreeIter = treeIter;
 }
@@ -1500,7 +1584,7 @@ void CtMainWin::_on_treeview_event_after(GdkEvent* event)
     if (event->type == GDK_BUTTON_PRESS and event->button.button == 1)
     {
         if (_pCtConfig->treeClickFocusText) {
-            get_text_view().grab_focus();
+            _ctTextview.grab_focus();
         }
         if (_pCtConfig->treeClickExpand)
         {
@@ -1695,14 +1779,16 @@ void CtMainWin::_on_textview_populate_popup(Gtk::Menu* menu)
 {
     if (curr_tree_iter().get_node_syntax_highlighting() == CtConst::RICH_TEXT_ID)
     {
-        // todo:
-        /*for (auto menuitem: menu->get_children())
-            if (menu->)
-            try:
-                if menuitem.get_image().get_property("stock") == "ct_edit_paste":
-                    menuitem.set_sensitive(True)
-            except: pass
-        */
+        for (auto child: menu->get_children())
+        {
+            if (auto menuItem = dynamic_cast<Gtk::MenuItem*>(child))
+                if (menuItem->get_label() == "_Paste")
+                {
+                    menuItem->set_sensitive(true);
+                    break;
+                }
+        }
+
         if (hovering_link_iter_offset() >= 0)
         {
             Gtk::TextIter target_iter = curr_buffer()->get_iter_at_offset(hovering_link_iter_offset());
@@ -1722,16 +1808,16 @@ void CtMainWin::_on_textview_populate_popup(Gtk::Menu* menu)
                 if (do_set_cursor) curr_buffer()->place_cursor(target_iter);
             }
             //for (auto iter : menu->get_children()) menu->remove(*iter);
-            get_ct_menu().build_popup_menu(GTK_WIDGET(menu->gobj()), CtMenu::POPUP_MENU_TYPE::Link);
+            get_ct_menu().build_popup_menu(menu, CtMenu::POPUP_MENU_TYPE::Link);
         }
         else {
             //for (auto iter : menu->get_children()) menu->remove(*iter);
-            get_ct_menu().build_popup_menu(GTK_WIDGET(menu->gobj()), CtMenu::POPUP_MENU_TYPE::Text);
+            get_ct_menu().build_popup_menu(menu, CtMenu::POPUP_MENU_TYPE::Text);
         }
     }
     else {
         //for (auto iter : menu->get_children()) menu->remove(*iter);
-        _uCtActions->getCtMainWin()->get_ct_menu().build_popup_menu(GTK_WIDGET(menu->gobj()), CtMenu::POPUP_MENU_TYPE::Code);
+        _uCtActions->getCtMainWin()->get_ct_menu().build_popup_menu(menu, CtMenu::POPUP_MENU_TYPE::Code);
     }
 }
 
@@ -1743,12 +1829,12 @@ bool CtMainWin::_on_textview_motion_notify_event(GdkEventMotion* event)
     if (curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID
         and curr_tree_iter().get_node_syntax_highlighting() != CtConst::PLAIN_TEXT_ID)
     {
-        get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+        _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
     int x, y;
-    get_text_view().window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
-    get_text_view().cursor_and_tooltips_handler(x, y);
+    _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, (int)event->x, (int)event->y, x, y);
+    _ctTextview.cursor_and_tooltips_handler(x, y);
     return false;
 }
 
@@ -1758,14 +1844,14 @@ bool CtMainWin::_on_textview_visibility_notify_event(GdkEventVisibility*)
     if (curr_tree_iter().get_node_syntax_highlighting() != CtConst::RICH_TEXT_ID and
         curr_tree_iter().get_node_syntax_highlighting() != CtConst::PLAIN_TEXT_ID)
     {
-        get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
+        _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->set_cursor(Gdk::Cursor::create(Gdk::XTERM));
         return false;
     }
     int x,y, bx, by;
     Gdk::ModifierType mask;
-    get_text_view().get_window(Gtk::TEXT_WINDOW_TEXT)->get_pointer(x, y, mask);
-    get_text_view().window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, x, y, bx, by);
-    get_text_view().cursor_and_tooltips_handler(bx, by);
+    _ctTextview.get_window(Gtk::TEXT_WINDOW_TEXT)->get_pointer(x, y, mask);
+    _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, x, y, bx, by);
+    _ctTextview.cursor_and_tooltips_handler(bx, by);
     return false;
 }
 
@@ -1784,12 +1870,29 @@ void CtMainWin::_on_textview_size_allocate(Gtk::Allocation& allocation)
     }
 }
 
+bool CtMainWin::_try_move_focus_to_anchored_widget_if_on_it()
+{
+    auto iter_insert = _ctTextview.get_buffer()->get_insert()->get_iter();
+    auto widgets = curr_tree_iter().get_embedded_pixbufs_tables_codeboxes(iter_insert.get_offset(), iter_insert.get_offset());
+    if (not widgets.empty()) {
+        if (CtCodebox* pCodebox = dynamic_cast<CtCodebox*>(widgets.front())) {
+            pCodebox->get_text_view().grab_focus();
+            return true;
+        }
+        if (CtTable* pTable = dynamic_cast<CtTable*>(widgets.front())) {
+            pTable->get_table_matrix().at(pTable->current_row()).at(pTable->current_column())->get_text_view().grab_focus();
+            return true;
+        }
+    }
+    return false;
+}
+
 bool CtMainWin::_on_textview_event(GdkEvent* event)
 {
     if (event->type != GDK_KEY_PRESS)
         return false;
 
-    auto curr_buffer = get_text_view().get_buffer();
+    auto curr_buffer = _ctTextview.get_buffer();
     if (event->key.state & Gdk::SHIFT_MASK)
     {
         if (event->key.keyval == GDK_KEY_ISO_Left_Tab and !curr_buffer->get_has_selection())
@@ -1798,30 +1901,17 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
             CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
             if (list_info and list_info.level)
             {
-                get_text_view().list_change_level(iter_insert, list_info, false);
+                _ctTextview.list_change_level(iter_insert, list_info, false);
                 return true;
             }
         }
     }
     else if (event->key.state & Gdk::CONTROL_MASK and event->key.keyval == GDK_KEY_space)
     {
-        auto iter_insert = curr_buffer->get_insert()->get_iter();
-        auto widgets = curr_tree_iter().get_embedded_pixbufs_tables_codeboxes(iter_insert.get_offset(), iter_insert.get_offset());
-        if (not widgets.empty()) {
-            if (CtCodebox* codebox = dynamic_cast<CtCodebox*>(widgets.front()))
-            {
-                codebox->get_text_view().grab_focus();
-                return true;
-            }
-            if (CtTable* table = dynamic_cast<CtTable*>(widgets.front()))
-            {
-                const CtTableMatrix& tableMatrix = table->get_table_matrix();
-                if (tableMatrix.size() and tableMatrix.front().size()) {
-                    tableMatrix.front().front()->get_text_view().grab_focus();
-                }
-                return true;
-            }
+        if (_try_move_focus_to_anchored_widget_if_on_it()) {
+            return true;
         }
+        auto iter_insert = _ctTextview.get_buffer()->get_insert()->get_iter();
         CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
         if (list_info and list_info.type == CtListType::Todo)
             if (_uCtActions->_is_curr_node_not_read_only_or_error())
@@ -1875,7 +1965,7 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
             CtListInfo list_info = CtList(this, curr_buffer).get_paragraph_list_info(iter_insert);
             if (list_info)
             {
-                get_text_view().list_change_level(iter_insert, list_info, true);
+                _ctTextview.list_change_level(iter_insert, list_info, true);
                 return true;
             }
         }
@@ -1896,7 +1986,7 @@ bool CtMainWin::_on_textview_event(GdkEvent* event)
             if (dynamic_cast<CtTable*>(widgets.front()))
             {
                 curr_buffer->place_cursor(iter_sel_end);
-                get_text_view().grab_focus();
+                _ctTextview.grab_focus();
                 return true;
             }
             else
@@ -1924,27 +2014,27 @@ void CtMainWin::_on_textview_event_after(GdkEvent* event)
 {
     if (event->type == GDK_2BUTTON_PRESS and event->button.button == 1)
     {
-        get_text_view().for_event_after_double_click_button1(event);
+        _ctTextview.for_event_after_double_click_button1(event);
     }
     if (event->type == GDK_3BUTTON_PRESS and event->button.button == 1)
     {
         if (curr_tree_iter().get_node_is_rich_text() and _pCtConfig->tripleClickParagraph)
-            if (get_text_view().get_todo_rotate_time() != event->button.time)
-                get_text_view().for_event_after_triple_click_button1(event);
+            if (_ctTextview.get_todo_rotate_time() != event->button.time)
+                _ctTextview.for_event_after_triple_click_button1(event);
     }
     else if (event->type == GDK_BUTTON_PRESS or event->type == GDK_KEY_PRESS)
     {
         if (curr_tree_iter() and not curr_buffer()->get_modified())
         {
-            get_state_machine().update_curr_state_cursor_pos(curr_tree_iter().get_node_id());
+            _ctStateMachine.update_curr_state_cursor_pos(curr_tree_iter().get_node_id());
         }
         if (event->type == GDK_BUTTON_PRESS)
         {
-            get_text_view().for_event_after_button_press(event);
+            _ctTextview.for_event_after_button_press(event);
         }
         if (event->type == GDK_KEY_PRESS)
         {
-            get_text_view().for_event_after_key_press(event, curr_tree_iter().get_node_syntax_highlighting());
+            _ctTextview.for_event_after_key_press(event, curr_tree_iter().get_node_syntax_highlighting());
         }
     }
     else if (event->type == GDK_KEY_RELEASE)
