@@ -204,7 +204,7 @@ void CtTreeIter::remove_all_embedded_widgets()
     }
 }
 
-std::list<CtAnchoredWidget*> CtTreeIter::get_embedded_pixbufs_tables_codeboxes_fast()
+std::list<CtAnchoredWidget*> CtTreeIter::get_embedded_pixbufs_tables_codeboxes_fast(const char doSort)
 {
     if (*this)
     {
@@ -226,9 +226,30 @@ std::list<CtAnchoredWidget*> CtTreeIter::get_embedded_pixbufs_tables_codeboxes_f
             (*this)->set_value(_pColumns->colAnchoredWidgets, retAnchoredWidgetsList);
         }
 
+        if (doSort != 'n') {
+            if (doSort == 'd') {
+                // desc
+                struct {
+                    bool operator()(CtAnchoredWidget* a, CtAnchoredWidget* b) const {
+                        return *a > *b;
+                    }
+                } customCompare;
+                retAnchoredWidgetsList.sort(customCompare);
+            }
+            else {
+                // asc
+                struct {
+                    bool operator()(CtAnchoredWidget* a, CtAnchoredWidget* b) const {
+                        return *a < *b;
+                    }
+                } customCompare;
+                retAnchoredWidgetsList.sort(customCompare);
+            }
+        }
+
         return retAnchoredWidgetsList;
     }
-    return std::list<CtAnchoredWidget*>();
+    return std::list<CtAnchoredWidget*>{};
 }
 
 std::list<CtAnchoredWidget*> CtTreeIter::get_embedded_pixbufs_tables_codeboxes(int start_offset /*= -1*/, int end_offset /*= -1*/)
@@ -318,9 +339,8 @@ bool CtDragStore::drag_data_received_vfunc(const Gtk::TreeModel::Path& dest, con
     return _pCtMainWin->get_ct_actions()->node_move(src, dest, false);
 }
 
-
-
 /********************************************************/
+
 CtTreeStore::CtTreeStore(CtMainWin* pCtMainWin)
  : _pCtMainWin(pCtMainWin)
 {
@@ -358,23 +378,7 @@ void CtTreeStore::_iter_delete_anchored_widgets(const Gtk::TreeModel::Children&
     }
 }
 
-void CtTreeStore::treevew_expand_to_tree_row(Gtk::TreeView* pTreeView, Gtk::TreeRow& row)
-{
-    Gtk::TreeIter iterParent = row.parent();
-    if (static_cast<bool>(iterParent))
-    {
-        pTreeView->expand_to_path(_rTreeStore->get_path(iterParent));
-    }
-}
-
-void CtTreeStore::treeview_safe_set_cursor(Gtk::TreeView* pTreeView, Gtk::TreeIter& treeIter)
-{
-    Gtk::TreeRow row = *treeIter;
-    treevew_expand_to_tree_row(pTreeView, row);
-    pTreeView->set_cursor(_rTreeStore->get_path(treeIter));
-}
-
-void CtTreeStore::treeview_set_tree_path_n_text_cursor(Gtk::TreeView* pTreeView,
+void CtTreeStore::treeview_set_tree_path_n_text_cursor(CtTreeView* pTreeView,
                                                        const std::string& node_path,
                                                        const int cursor_pos)
 {
@@ -384,7 +388,7 @@ void CtTreeStore::treeview_set_tree_path_n_text_cursor(Gtk::TreeView* pTreeView,
         Gtk::TreeIter treeIter = _rTreeStore->get_iter(node_path);
         if (static_cast<bool>(treeIter))
         {
-            treeview_safe_set_cursor(pTreeView, treeIter);
+            pTreeView->set_cursor_safe(treeIter);
             treeSelFromConfig = true;
             if (_pCtMainWin->get_ct_config()->treeClickExpand)
             {
@@ -837,7 +841,9 @@ bool CtTreeStore::is_node_bookmarked(const gint64 node_id)
 
 std::string CtTreeStore::get_node_name_from_node_id(const gint64 node_id)
 {
-    return _nodes_names_dict.at(node_id);
+    auto iter = _nodes_names_dict.find(node_id); // node_id from link can be invalid
+    if (iter != _nodes_names_dict.end()) return iter->second;
+    return "";
 }
 
 CtTreeIter CtTreeStore::get_node_from_node_id(const gint64 node_id)
